Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(669)

Unified Diff: runtime/vm/flow_graph_compiler_x64.cc

Issue 23190035: Distinguish between malformed and malbounded types (fix issues 12552 and 12554). (Closed) Base URL: http://dart.googlecode.com/svn/branches/bleeding_edge/dart/
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/flow_graph_compiler_mips.cc ('k') | runtime/vm/flow_graph_optimizer.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/flow_graph_compiler_x64.cc
===================================================================
--- runtime/vm/flow_graph_compiler_x64.cc (revision 26663)
+++ runtime/vm/flow_graph_compiler_x64.cc (working copy)
@@ -573,7 +573,7 @@
const AbstractType& type,
bool negate_result,
LocationSummary* locs) {
- ASSERT(type.IsFinalized() && !type.IsMalformed());
+ ASSERT(type.IsFinalized() && !type.IsMalformed() && !type.IsMalbounded());
const Immediate& raw_null =
Immediate(reinterpret_cast<intptr_t>(Object::null()));
@@ -663,7 +663,7 @@
ASSERT(!dst_type.IsNull());
ASSERT(dst_type.IsFinalized());
// Assignable check is skipped in FlowGraphBuilder, not here.
- ASSERT(dst_type.IsMalformed() ||
+ ASSERT(dst_type.IsMalformed() || dst_type.IsMalbounded() ||
(!dst_type.IsDynamicType() && !dst_type.IsObjectType()));
__ pushq(RCX); // Store instantiator.
__ pushq(RDX); // Store instantiator type arguments.
@@ -681,9 +681,15 @@
__ j(EQUAL, &is_assignable);
}
- // Generate throw new TypeError() if the type is malformed.
- if (dst_type.IsMalformed()) {
- const Error& error = Error::Handle(dst_type.malformed_error());
+ // Generate throw new TypeError() if the type is malformed or malbounded.
+ if (dst_type.IsMalformed() || dst_type.IsMalbounded()) {
+ Error& error = Error::Handle();
+ if (dst_type.IsMalformed()) {
+ error = dst_type.malformed_error();
+ } else {
+ const bool is_malbounded = dst_type.IsMalboundedWithError(&error);
+ ASSERT(is_malbounded);
+ }
const String& error_message = String::ZoneHandle(
Symbols::New(error.ToErrorCString()));
__ PushObject(Object::ZoneHandle()); // Make room for the result.
« no previous file with comments | « runtime/vm/flow_graph_compiler_mips.cc ('k') | runtime/vm/flow_graph_optimizer.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698